'use strict';

require('path');
require('hable');
require('signal-exit');
const __chunk_1 = require('./tib-chunk.js');
require('os');
require('child_process');
require('tree-kill');
require('vue-template-compiler');
require('@babel/core');
require('@babel/parser');
require('./tib-chunk2.js');
require('./tib-chunk3.js');
const index = require('./tib-index.js');
const __chunk_4 = require('./tib-chunk4.js');

class SauceLabsBrowser extends __chunk_4.SeleniumLogging(index.default) {
  /* istanbul ignore next */
  constructor(config) {
    config.xvfb = false;

    super(config);

    this.hook('selenium:build:before', (builder) => {
      const user = this.getConfigProperty('user');
      const key = this.getConfigProperty('key');
      builder.usingServer(`http://${user}:${key}@ondemand.saucelabs.com:80/wd/hub`);
    });

    throw new __chunk_1.BrowserError(this, `SauceLabs not yet implemented`)
  }

  /* istanbul ignore next */
  getConfigProperty(property, capabilities = {}, defaulValue) {
    const envKey = `BROWSERSTACK_${property.toUpperCase()}`;
    if (process.env[envKey]) {
      return process.env[envKey]
    }

    const confKey = `browserstack.${property}`;

    if (capabilities[confKey]) {
      return capabilities[confKey]
    }

    if (this.config.SauceLabsLocal && this.config.SauceLabsLocal[property]) {
      return this.config.SauceLabsLocal[property]
    }

    if (this.config.SauceLabs && this.config.SauceLabs[property]) {
      return this.config.SauceLabs[property]
    }

    if (typeof defaulValue !== 'undefined') {
      return defaulValue
    }

    throw new Error(`${this.constructor.name} could not resolve required config property '${property}'`)
  }

  /* istanbul ignore next */
  async _start(capabilities = {}) {
    this.addCapabilities({
      'browserstack.user': this.getConfigProperty('user', capabilities),
      'browserstack.key': this.getConfigProperty('key', capabilities),
      'browserstack.debug': this.getConfigProperty('debug', capabilities, false)
    });

    await super._start(capabilities);
  }

  /* istanbul ignore next */
  setOS(name, version = '') {
    return this.addCapability('platform', `${name}${version ? ' ' : ''}${version || ''}`)
  }

  /* istanbul ignore next */
  getBrowserVersion() {
    return this.getCapability('version')
  }

  /* istanbul ignore next */
  setBrowserVersion(version) {
    return this.addCapability('version', version)
  }

  /* istanbul ignore next */
  setDevice(deviceName) {
    return this.addCapability('device', deviceName)
  }
}

exports.default = SauceLabsBrowser;
